@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2016 DreamWorks Animation LLC
+// Copyright (c) DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -27,19 +27,13 @@
 // LIABILITY FOR ALL CLAIMS REGARDLESS OF THEIR BASIS EXCEED US$250.00.
 //
 ///////////////////////////////////////////////////////////////////////////
-//
+
 /// @file GridTransformer.h
 /// @author Peter Cucka
 
 #ifndef OPENVDB_TOOLS_GRIDTRANSFORMER_HAS_BEEN_INCLUDED
 #define OPENVDB_TOOLS_GRIDTRANSFORMER_HAS_BEEN_INCLUDED
 
-#include <cmath>
-#include <boost/bind.hpp>
-#include <boost/function.hpp>
-#include <boost/shared_ptr.hpp>
-#include <tbb/blocked_range.h>
-#include <tbb/parallel_reduce.h>
 #include <openvdb/Grid.h>
 #include <openvdb/Types.h>
 #include <openvdb/math/Math.h> // for isApproxEqual()
@@ -49,6 +43,10 @@
 #include "LevelSetRebuild.h" // for doLevelSetRebuild()
 #include "SignedFloodFill.h" // for signedFloodFill
 #include "Prune.h" // for pruneLevelSet
+#include <tbb/blocked_range.h>
+#include <tbb/parallel_reduce.h>
+#include <cmath>
+#include <functional>
 
 namespace openvdb {
 OPENVDB_USE_VERSION_NAMESPACE
@@ -120,7 +118,7 @@ template<typename Sampler, typename TreeT>
 class TileSampler: public Sampler
 {
 public:
-    typedef typename TreeT::ValueType ValueT;
+    using ValueT = typename TreeT::ValueType;
 
     /// @param b        the index-space bounding box of a particular grid tile
     /// @param tileVal  the tile's value
@@ -187,12 +185,15 @@ public:
 class GridResampler
 {
 public:
-    typedef boost::shared_ptr<GridResampler> Ptr;
-    typedef boost::function<bool (void)> InterruptFunc;
+    using Ptr = SharedPtr<GridResampler>;
+    using InterruptFunc = std::function<bool (void)>;
 
     GridResampler(): mThreaded(true), mTransformTiles(true) {}
     virtual ~GridResampler() {}
 
+    GridResampler(const GridResampler&) = default;
+    GridResampler& operator=(const GridResampler&) = default;
+
     /// Enable or disable threading.  (Threading is enabled by default.)
     void setThreaded(bool b) { mThreaded = b; }
     /// Return @c true if threading is enabled.
@@ -255,7 +256,7 @@ private:
 class GridTransformer: public GridResampler
 {
 public:
-    typedef boost::shared_ptr<GridTransformer> Ptr;
+    using Ptr = SharedPtr<GridTransformer>;
 
     GridTransformer(const Mat4R& xform);
     GridTransformer(
@@ -265,7 +266,10 @@ public:
         const Vec3R& translate,
         const std::string& xformOrder = "tsr",
         const std::string& rotationOrder = "zyx");
-    virtual ~GridTransformer() {}
+    ~GridTransformer() override = default;
+
+    GridTransformer(const GridTransformer&) = default;
+    GridTransformer& operator=(const GridTransformer&) = default;
 
     const Mat4R& getTransform() const { return mTransform; }
 
@@ -491,10 +495,14 @@ resampleToMatch(const GridType& inGrid, GridType& outGrid, Interrupter& interrup
 
         // If the output grid is a level set, resample the input grid to have the output grid's
         // background value.  Otherwise, preserve the input grid's background value.
-        typedef typename GridType::ValueType ValueT;
-        const ValueT halfWidth = ((outGrid.getGridClass() == openvdb::GRID_LEVEL_SET)
+        using ValueT = typename GridType::ValueType;
+        const bool outIsLevelSet = outGrid.getGridClass() == openvdb::GRID_LEVEL_SET;
+
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
+        const ValueT halfWidth = outIsLevelSet
             ? ValueT(outGrid.background() * (1.0 / outGrid.voxelSize()[0]))
-            : ValueT(inGrid.background() * (1.0 / inGrid.voxelSize()[0])));
+            : ValueT(inGrid.background() * (1.0 / inGrid.voxelSize()[0]));
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_END
 
         typename GridType::Ptr tempGrid;
         try {
@@ -673,7 +681,7 @@ template<typename InterrupterType>
 void
 GridResampler::setInterrupter(InterrupterType& interrupter)
 {
-    mInterrupt = boost::bind(&InterrupterType::wasInterrupted,
+    mInterrupt = std::bind(&InterrupterType::wasInterrupted,
         /*this=*/&interrupter, /*percent=*/-1);
 }
 
@@ -756,12 +764,12 @@ template<class Sampler, class TreeT, typename Transformer>
 class GridResampler::RangeProcessor
 {
 public:
-    typedef typename TreeT::LeafCIter LeafIterT;
-    typedef typename TreeT::ValueAllCIter TileIterT;
-    typedef typename tree::IteratorRange<LeafIterT> LeafRange;
-    typedef typename tree::IteratorRange<TileIterT> TileRange;
-    typedef typename tree::ValueAccessor<const TreeT> InTreeAccessor;
-    typedef typename tree::ValueAccessor<TreeT> OutTreeAccessor;
+    using LeafIterT = typename TreeT::LeafCIter;
+    using TileIterT = typename TreeT::ValueAllCIter;
+    using LeafRange = typename tree::IteratorRange<LeafIterT>;
+    using TileRange = typename tree::IteratorRange<TileIterT>;
+    using InTreeAccessor = typename tree::ValueAccessor<const TreeT>;
+    using OutTreeAccessor = typename tree::ValueAccessor<TreeT>;
 
     RangeProcessor(const Transformer& xform, const CoordBBox& b, const TreeT& inT, TreeT& outT):
         mIsRoot(true), mXform(xform), mBBox(b),
@@ -868,11 +876,11 @@ void
 GridResampler::applyTransform(const Transformer& xform,
     const GridT& inGrid, GridT& outGrid) const
 {
-    typedef typename GridT::TreeType TreeT;
+    using TreeT = typename GridT::TreeType;
     const TreeT& inTree = inGrid.tree();
     TreeT& outTree = outGrid.tree();
 
-    typedef RangeProcessor<Sampler, TreeT, Transformer> RangeProc;
+    using RangeProc = RangeProcessor<Sampler, TreeT, Transformer>;
 
     const GridClass gridClass = inGrid.getGridClass();
 
@@ -937,13 +945,13 @@ GridResampler::transformBBox(
     const InterruptFunc& interrupt,
     const Sampler& sampler)
 {
-    typedef typename OutTreeT::ValueType ValueT;
+    using ValueT = typename OutTreeT::ValueType;
 
     // Transform the corners of the input tree's bounding box
     // and compute the enclosing bounding box in the output tree.
     Vec3R
         inRMin(bbox.min().x(), bbox.min().y(), bbox.min().z()),
-        inRMax(bbox.max().x(), bbox.max().y(), bbox.max().z()),
+        inRMax(bbox.max().x()+1, bbox.max().y()+1, bbox.max().z()+1),
         outRMin = math::minComponent(xform.transform(inRMin), xform.transform(inRMax)),
         outRMax = math::maxComponent(xform.transform(inRMin), xform.transform(inRMax));
     for (int i = 0; i < 8; ++i) {
@@ -1034,6 +1042,6 @@ GridResampler::transformBBox(
 
 #endif // OPENVDB_TOOLS_GRIDTRANSFORMER_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2016 DreamWorks Animation LLC
+// Copyright (c) DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
